@@ -38,7 +38,9 @@ typedef unsigned char cbyte;
 
 /* #define FORCELOCALE*/
 
+#ifndef NOLONGDOUBLE
 char *Genround(long double , int );
+#endif
 char *Genround(char*, int );
 char *Genround(long long int , int );
 char *Genround(short int , int );
@@ -51,12 +53,18 @@ uint64_t Checksum_bytes(uint64_t , cbyte* , int );
 uint64_t CRC64(uint64_t , cbyte* , int );
 char* Canonicalize_unicode(const char*, char*, int*);
 
+#ifdef NOLONGDOUBLE
+uint64_t UNF1 (double , int , uint64_t , int ) ;
+uint64_t UNF2 (double , int , uint64_t , int ) ;
+int UNF3 (double , int , md5_state_t* , int ) ;
+#else
 uint64_t UNF1 (long double , int , uint64_t , int ) ;
-uint64_t UNF1 (char* , int , uint64_t , int ) ;
 uint64_t UNF2 (long double , int , uint64_t , int ) ;
-uint64_t UNF2 (char* , int , uint64_t , int ) ;
-int UNF3 (char*, int , md5_state_t* , int );
 int UNF3 (long double , int , md5_state_t* , int ) ;
+#endif
+uint64_t UNF1 (char* , int , uint64_t , int ) ;
+int UNF3 (char*, int , md5_state_t* , int );
+uint64_t UNF2 (char* , int , uint64_t , int ) ;
 int UNF_init(int) ;
 
 void tobase64(unsigned char *out, md5_byte_t *in, int inlen);
